function [prmin,psomin,negir,negiso,negtd] = NegativeParameters(R,W,bursttype)
    % [prmin,psomin,negir,negiso,negtd] = NegativeParameters(R,W,bursttype)
	%  negativeparameters(Z,Wroot,bursttype) - 'Finds' the scaled blast wave
	%  parameters for a given scaled distance depending on the 'bursttype'
	%  (1 for surface, 2 for free air). Parameters are found using simple
	%  curve fits of the empirical Kingery and Bulmash data. Scaled time
	%  and impluse values are given in real dimensions using the cubed root
	%  of explosive mass, Wroot.
%========================================================================% 
Wroot = W^(1/3);
Z = R/Wroot;

if bursttype==1;
    % SURFACE BURST
    
    % Peak negative reflected pressure
    %================================%
    if (Z <= 0.669);
        A = 0; B = 0; C = 0; D = 100E-3;
    elseif (Z > 0.669) && (Z <= 1.27);  
        A = -32.91E-3; B = 2; C = 13E-3; D = 106E-3;
    elseif (Z > 1.27) && (Z <= 2.78);  
        A = 93E-3; B = -1.215; C = 0; D = 0; 
    elseif (Z > 2.78);  
        A = 72.99E-3; B = -0.978; C = 0; D = 0;    
    end
    prmin = 1000 * (( A * ( Z ^ B ) ) + ( C * Z ) + D);

    % Peak negative incident pressure
    %================================%    
    if (Z <= 0.395);
        A = 0; B = 0; C = 0; D = 100E-3;
    elseif (Z > 0.4888) && (Z <= 1.41);  
        A = -39.25E-3; B = 2; C = 11E-3; D = 104E-3;
    elseif (Z > 1.41) && (Z <= 1.92);  
        A = 44.16E-3; B = 2; C = -182.12E-3;  D = 211E-3;
    elseif (Z > 1.92) && (Z <= 3.21);  
        A = 50.169E-3; B = -1.158; C = 0; D = 0;         
    elseif (Z > 3.21);  
        A = 41.467E-3; B = -0.994; C = 0; D = 0;    
    end
    psomin = 1000 * (( A * ( Z ^ B ) ) + ( C * Z ) + D);
    
    % Negative specific reflected impulse
    %====================================%    
    if (Z <= 0.58);
        A = -724.37E-3; B = 2; C = 445.34E-3; D = 553E-3;
    elseif (Z > 0.58) && (Z <= 1.19);  
        A = 11.356E-3; B = 2; C = -314.76E-3; D = 752E-3;
    elseif (Z > 1.19) && (Z <= 5.25);  
        A = 461.8E-3; B = -0.88; C = 0; D = 0;
    elseif (Z > 5.25);  
        A = 433.6E-3; B = -0.842; C = 0; D = 0;    
    end
    negir = Wroot * (1000 * (( A * ( Z ^ B ) ) + ( C * Z ) + D));
    
    % Negative specific incident impulse
    %===================================%
    if (Z <= 0.535);
        A = -724.37E-3; B = 2; C = 445.34E-3; D = 553E-3;
    elseif (Z > 0.535) && (Z <= 1.54);  
        A = 202.71E-3; B = 2; C = -794.62E-3; D = 951E-3;
    elseif (Z > 1.54) && (Z <= 4.99);  
        A = 316.94E-3; B = -0.974; C = 0; D = 0;
    elseif (Z > 4.99) && (Z <= 7.51);  
        A = 394.4E-3; B = -1.11; C = 0; D = 0;        
    elseif (Z > 7.51) && (Z <= 16.5);  
        A = 270.5E-3; B = -0.923; C = 0; D = 0;
    elseif (Z > 16.5);  
        A = 511E-3; B = -1.15; C = 0; D = 0;    
    end
    negiso = Wroot * (1000 * (( A * ( Z ^ B ) ) + ( C * Z ) + D));

    % Negative phase duration
    %=========================%
    if (Z <= 0.267);
        A = 0; B = 0; C = 0; D = 10.57; 
    elseif (Z > 0.267) && (Z <= 2.9);  
        A = -0.474; B = 2; C = 2.745; D = 9.87;
    elseif (Z > 2.9);  
        A = 0; B = 0; C = 0;
        D = 13.9;    
    end
    negtd = Wroot * (( A * ( Z ^ B ) ) + ( C * Z ) + D);
    
%========================================================================%
elseif bursttype==2;
    % FREE AIR BURST
    
    % Peak negative reflected pressure
    %================================%    
    if (Z <= 0.7);
        A = 0; B = 0; C = 0; D = 100E-3;
    elseif (Z > 0.7) && (Z <= 1.469);  
        A = -29.078E-3; B = 2; C = 0.0352E-3; D = 114E-3;
    elseif (Z > 1.469) && (Z <= 2.754);  
        A = 84.132E-3; B = -1.286; C = 0; D = 0;
    elseif (Z > 2.754);  
        A = 59.559E-3; B = -0.945; C = 0; D = 0;    
    end
    prmin = 1000 * (( A * ( Z ^ B ) ) + ( C * Z ) + D);
    
    % Peak negative incident pressure
    %================================%
    if (Z <= 0.576);
        A = 0; B = 0; C = 0; D = 100E-3;
    elseif (Z > 0.576) && (Z <= 1.177);  
        A = -63.525E-3; B = 2; C = 32.434E-3; D = 102E-3;
    elseif (Z > 1.177) && (Z <= 1.843);  
        A = 71.583E-3; B = -1.893; C = 0; D = 0;      
    elseif (Z > 1.843);  
        A = 46.807E-3; B = -1.198; C = 0; D = 0;    
    end
    psomin = 1000 * (( A * ( Z ^ B ) ) + ( C * Z ) + D);

    % Negative specific reflected impulse
    %====================================%    
    if (Z <= 0.304);
        A = 0; B = 0; C = 0; D = 496E-3;
    elseif (Z > 0.304) && (Z <= 1.44);  
        A = 36.919E-3; B = 2; C = -298.72E-3; D = 583E-3;
    elseif (Z > 1.44);  
        A = 316.36E-3; B = -0.879; C = 0; D = 0;    
    end 
    negir = Wroot * (1000 * (( A * ( Z ^ B ) ) + ( C * Z ) + D));
    
    % Negative specific incident impulse
    %===================================%
    if (Z <= 0.3);
        A = 0; B = 0; C = 0; D = 496E-3;
    elseif (Z > 0.3) && (Z <= 1.108);  
        A = 212E-3; B = 2; C = -657E-3; D = 674E-3;
    elseif (Z > 1.108) && (Z <= 2.209);  
        A = 231E-3; B = -1.118; C = 0; D = 0;
    elseif (Z > 2.209);  
        A = 208E-3; B = -0.9851; C = 0; D = 0;    
    end
    negiso = Wroot * (1000 * (( A * ( Z ^ B ) ) + ( C * Z ) + D));
    
    % Negative phase duration
    %=========================%
    if (Z <= 0.537);
        A = 0.382;  B = 2;  C = 2.952; D = 7.917;
    elseif (Z > 0.537) && (Z <= 2.83);  
        A = -0.309; B = 2; C = 1.6443; D = 8.818;
    elseif (Z > 2.83);  
        A = 0; B = 0; C = 0; D = 11.0;    
    end
    negtd = Wroot * (( A * ( Z ^ B ) ) + ( C * Z ) + D);
    
end