function [psomax,prmax,ta,td,iso,ir] = PositiveParameters(R,W,bursttype,air,surface)
    % [psomax,prmax,ta,td,iso,ir] = PositiveParameters(R,W,bursttype,air,surface)
    % PositiveParameters.m finds blast wave parameters for any value of R, W
    % and bursttype (1 for surface burst, 2 for free air) by
    % interpolating values given by ConWep.
    % If 'ConWepVals' has already been read, can be used as input to avoid 
    % reading in within function (to save time within loop)

Wroot = W^(1/3);
Z = R/Wroot;

    if Z < 0.07079 && bursttype == 1;
        clc
        disp(['WARNING - Z = ' num2str(Z) ' m/kg^1/3'])
        disp('        - Scaled distance is too small for blast parameter calculations')
        disp('        - Scaled distance must be greater than 0.07079 m/kg^1/3')
    elseif Z < 0.05623 && bursttype == 2;
        clc
        disp(['WARNING - Z = ' num2str(Z) ' m/kg^1/3'])
        disp('        - Scaled distance is too small for blast parameter calculations')
        disp('        - Scaled distance must be greater than 0.05623 m/kg^1/3')
    elseif (Z > 37.58)
        clc
        disp(['WARNING - Z = ' num2str(Z) 'm/kg^1/3'])
        disp('        - Scaled distance is too large for blast parameter calculations')
        disp('        - Scaled distance must be less than 37.58 m/kg^1/3')
    end

if nargin < 4    
    load('ConWepValues')
end
if bursttype == 1
    psomax = 10^(interp1(log10(surface(:,1)),log10(surface(:,2)),log10(Z),'cubic'));
    prmax = 10^(interp1(log10(surface(:,1)),log10(surface(:,3)),log10(Z),'cubic'));
    ta = Wroot * 10^(interp1(log10(surface(:,1)),log10(surface(:,4)),log10(Z),'cubic'));
    td = Wroot * 10^(interp1(log10(surface(:,1)),log10(surface(:,5)),log10(Z),'cubic'));
    iso = Wroot * 10^(interp1(log10(surface(:,1)),log10(surface(:,6)),log10(Z),'cubic'));
    ir = Wroot * 10^(interp1(log10(surface(:,1)),log10(surface(:,7)),log10(Z),'cubic'));
else
    psomax = 10^(interp1(log10(air(:,1)),log10(air(:,2)),log10(Z),'cubic'));
    prmax = 10^(interp1(log10(air(:,1)),log10(air(:,3)),log10(Z),'cubic'));
    ta = Wroot * 10^(interp1(log10(air(:,1)),log10(air(:,4)),log10(Z),'cubic'));
    td = Wroot * 10^(interp1(log10(air(:,1)),log10(air(:,5)),log10(Z),'cubic'));
    iso = Wroot * 10^(interp1(log10(air(:,1)),log10(air(:,6)),log10(Z),'cubic'));
    ir = Wroot * 10^(interp1(log10(air(:,1)),log10(air(:,7)),log10(Z),'cubic'));
end


if nargin == 3
disp('INPUT')
    if bursttype ==1
        disp('    Hemispherical Surface Burst')
    elseif bursttype == 2
        disp('    Spherical Free-Air Burst')
    end
    disp(['    Equivalent charge mass       = ' num2str(W) ' kg'])
    disp(['    Stand-off                    = ' num2str(R) ' m'])
    disp(['    Scaled Distance              = ' num2str(Z) ' m/kg^1/3'])
    disp('OUTPUT')
    disp(['    Peak incident overpressure   = ' num2str(psomax) ' kPa'])
    disp(['    Peak reflected overpressure  = ' num2str(prmax) ' kPa'])
    disp(['    Time of arrival              = ' num2str(ta) ' ms'])
    disp(['    Positive phase duration      = ' num2str(td) ' ms'])
    disp(['    Incident impulse             = ' num2str(iso) ' kPa-ms'])
    disp(['    Reflected impulse            = ' num2str(ir) ' kPa-ms'])
end
end